summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorFederico Razzoli <federico.razzoli@vettabase.com>2021-04-26 23:00:33 +0100
committerVladislav Vaintroub <wlad@mariadb.com>2022-04-26 15:56:58 +0200
commit81862dbb087216ab82cfa228af7463c83d15e617 (patch)
treee681dffff4fc277a8a3c1d07744380f5ad00b2da /scripts
parente135edec3a33748c59cac1aba9017a9ec8ff7dc5 (diff)
downloadmariadb-git-81862dbb087216ab82cfa228af7463c83d15e617.tar.gz
MDEV-28340 sys.table_exists: support table_type=SEQUENCE
Diffstat (limited to 'scripts')
-rw-r--r--scripts/sys_schema/procedures/table_exists.sql5
1 files changed, 3 insertions, 2 deletions
diff --git a/scripts/sys_schema/procedures/table_exists.sql b/scripts/sys_schema/procedures/table_exists.sql
index e06d018308f..b76b83089e9 100644
--- a/scripts/sys_schema/procedures/table_exists.sql
+++ b/scripts/sys_schema/procedures/table_exists.sql
@@ -19,7 +19,7 @@ DELIMITER $$
CREATE DEFINER='mariadb.sys'@'localhost' PROCEDURE table_exists (
IN in_db VARCHAR(64), IN in_table VARCHAR(64),
- OUT out_exists ENUM('', 'BASE TABLE', 'VIEW', 'TEMPORARY')
+ OUT out_exists ENUM('', 'BASE TABLE', 'VIEW', 'TEMPORARY', 'SEQUENCE')
)
COMMENT '
Description
@@ -41,10 +41,11 @@ CREATE DEFINER='mariadb.sys'@'localhost' PROCEDURE table_exists (
out_exists ENUM('''', ''BASE TABLE'', ''VIEW'', ''TEMPORARY''):
The return value: whether the table exists. The value is one of:
* '''' - the table does not exist neither as a base table, view, nor temporary table.
* ''BASE TABLE'' - the table name exists as a permanent base table table.
* ''VIEW'' - the table name exists as a view.
* ''TEMPORARY'' - the table name exists as a temporary table.
+ * ''SEQUENCE'' - the table name exists as a sequence.
Example
--------
@@ -41,10 +41,11 @@ CREATE DEFINER='mariadb.sys'@'localhost' PROCEDURE table_exists (
out_exists ENUM('''', ''BASE TABLE'', ''VIEW'', ''TEMPORARY''):
The return value: whether the table exists. The value is one of:
- * '''' - the table does not exist neither as a base table, view, nor temporary table.
+ * '''' - the table does not exist neither as a base table, view, sequence nor temporary table.
* ''BASE TABLE'' - the table name exists as a permanent base table table.
* ''VIEW'' - the table name exists as a view.